pub enum Deletion {
File(Arc<Path>),
Dir(Arc<Path>),
}Expand description
Note: paths need to be absolute (or canonical), or using chdir in the app after starting the daemon will lead to breakage! Use the constructor functions rather than constructing this type directly!
Variants
File(Arc<Path>)
A single file, deleted via remove_file, does not work for dirs
Dir(Arc<Path>)
A directory, deleted via remove_dir_all, also works on
single files but is more dangerous.
Implementations
Sourceimpl Deletion
impl Deletion
Sourcepub fn file(path: impl IntoArcPath + AsRef<Path>) -> Result<Self>
pub fn file(path: impl IntoArcPath + AsRef<Path>) -> Result<Self>
Construct a single-file deletion action from a path; the path is made absolute based on the current cwd if needed, errors during that process are reported