pub struct CleanupDaemon { /* private fields */ }Implementations
Sourceimpl CleanupDaemon
impl CleanupDaemon
Sourcepub fn start() -> Result<Self>
pub fn start() -> Result<Self>
Create a daemon that can receive information about open
files. This forks a separate process into a new unix session
so that it is not killed. Must be run while there are no
additional threads, otherwise this panics! When the process
holding the CleanupDaemon struct (the parent) exits (in
whatever way), the forked daemon process detects the pipe
filehandles closing, and then deletes all files that haven’t
been cancelled.
Sourcepub fn send(&mut self, message: CleanupMessage) -> Result<()>
pub fn send(&mut self, message: CleanupMessage) -> Result<()>
Warning: only send absolute paths, or if you don’t, make sure that you don’t use chdir in the parent after starting the daemon!